@@ -1,6 +1,5 @@
 #[cfg(not(feature="serde_macros"))]
 mod inner {
-    extern crate syntex;
     extern crate serde_codegen;
 
     use std::env;
@@ -13,10 +12,7 @@ mod inner {
         let src = Path::new("src/jsontypes.rs.in");
         let dst = Path::new(&out_dir).join("jsontypes.rs");
 
-        let mut registry = syntex::Registry::new();
-
-        serde_codegen::register(&mut registry);
-        registry.expand("", &src, &dst).unwrap();
+        serde_codegen::expand(&src, &dst).unwrap();
     }
 }
 
